/*
 * CustomerClassBehavior.java
 * Copyright (c) 2011, W4.
 * All rights reserved.
 */

package GestionInterventions.behavior;

import leon.app.behavior.LyClassBehavior;
import leon.control.LyFormController;
import leon.control.LySetController;
import leon.data.LyFieldInfoValue;
import leon.data.LyObject;
import leon.data.LyObjectId;
import leon.info.LyClassInfo;
import leon.info.LyFieldInfo;
import GestionInterventions.src.GESTIONINTERVENTIONS;

/**
 * Generic interface for all behaviors that applies on action. This interface represents the default
 * behavior for consult, set, filter and delete actions.
 *
 * @author  Lyria S.A.
 * @version $Id: LyClassBehaviorInterface.java 28422 2010-11-03 12:03:38Z ehelmste $
 * @see     leon.app.behaviorinterface.LySetBehaviorInterface
 * @see     leon.app.behaviorinterface.LyCreateBehaviorInterface
 * @see     leon.app.behaviorinterface.LyDeleteBehaviorInterface
 * @see     leon.app.behaviorinterface.LyFilterBehaviorInterface
 */
public class CustomerClassBehavior extends LyClassBehavior
{
	/**
	 * Default Constructor
	 */
	public CustomerClassBehavior()
	{
	}

	
	
	@Override
	public void propagate(LySetController set, LyFieldInfoValue newValue) {

		super.propagate(set, newValue);
		
		LyFieldInfo fieldInfo = newValue.getFieldInfo();
		String fieldId = fieldInfo.getId();
		LyClassInfo customerCls = set.getClassInfo();
		//if the address field is null, its values are initialized
		if(set.isInitialized() && 
				fieldId.equals(GESTIONINTERVENTIONS.FLD_CUSTOMER_ADDRESS_LIST)){
			
			LyFormController addressController = (LyFormController)set.getAreaController(customerCls.getFieldInfo(
					GESTIONINTERVENTIONS.FLD_CUSTOMER_ADDRESS));
			
			if(addressController instanceof LySetController){

					if(!newValue.isNull()){
						LyObjectId addressId = (LyObjectId)newValue.getValue();
						LyObject address = addressId.getLogicalObject();
						LyClassInfo addressCls = address.getClassInfo();
						
						((LySetController)addressController).setFieldValue(
								addressCls.getFieldInfo(GESTIONINTERVENTIONS.FLD_ADDRESS_ADDRESS), 
								address.getValue(GESTIONINTERVENTIONS.FLD_ADDRESS_ADDRESS));
						
						((LySetController)addressController).setFieldValue(
								addressCls.getFieldInfo(GESTIONINTERVENTIONS.FLD_ADDRESS_CITY),
								address.getValue(GESTIONINTERVENTIONS.FLD_ADDRESS_CITY));
						
						((LySetController)addressController).setFieldValue(
								addressCls.getFieldInfo(GESTIONINTERVENTIONS.FLD_ADDRESS_COUNTRY), 
								address.getValue(GESTIONINTERVENTIONS.FLD_ADDRESS_COUNTRY));
						
						((LySetController)addressController).setFieldValue(
								addressCls.getFieldInfo(GESTIONINTERVENTIONS.FLD_ADDRESS_ZIPCODE), 
								address.getValue(GESTIONINTERVENTIONS.FLD_ADDRESS_ZIPCODE));
						
						((LySetController)addressController).setFieldValue(
								addressCls.getFieldInfo(GESTIONINTERVENTIONS.FLD_ADDRESS_LATITUDE), 
								address.getValue(GESTIONINTERVENTIONS.FLD_ADDRESS_LATITUDE));
						
						((LySetController)addressController).setFieldValue(
								addressCls.getFieldInfo(GESTIONINTERVENTIONS.FLD_ADDRESS_LONGITUDE), 
								address.getValue(GESTIONINTERVENTIONS.FLD_ADDRESS_LONGITUDE));

					}					
			}			
		}
	}
}
